@@ -6,7 +6,7 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{agreement::SectionSigned, relocation::RelocatePayload, section::NodeState};
+use super::{agreement::SectionSigned, section::NodeState};
 use crate::SectionAuthorityProvider;
 use ed25519_dalek::Signature;
 use secured_linked_list::SecuredLinkedList;
@@ -23,8 +23,6 @@ use threshold_crypto::PublicKey as BlsPublicKey;
 pub struct JoinRequest {
     /// The public key of the section to join.
     pub section_key: BlsPublicKey,
-    /// If the peer is being relocated, contains `RelocatePayload`. Otherwise contains `None`.
-    pub relocate_payload: Option<RelocatePayload>,
     /// Proof of the resouce proofing.
     pub resource_proof_response: Option<ResourceProofResponse>,
 }
@@ -34,13 +32,6 @@ impl Debug for JoinRequest {
         formatter
             .debug_struct("JoinRequest")
             .field("section_key", &self.section_key)
-            .field(
-                "relocate_payload",
-                &self
-                    .relocate_payload
-                    .as_ref()
-                    .map(|payload| &payload.details),
-            )
             .field(
                 "resource_proof_response",
                 &self
